Module allocation

Module allocation 

Structs

Allocation
Allocation is the fix41 Allocation type, MsgType = J.

Functions

route
Returns the begin string, message type, and route function for Allocation.

Type Aliases

Route
Route type returned by the route function.
RouteOut
RouteOut is the callback type for routing Allocation messages.