pub type RouteOut = fn(msg: Allocation, session_id: SessionID) -> Result<(), MessageRejectErrorEnum>;Expand description
RouteOut is the callback type for routing Allocation messages.
pub type RouteOut = fn(msg: Allocation, session_id: SessionID) -> Result<(), MessageRejectErrorEnum>;RouteOut is the callback type for routing Allocation messages.