pub type RouteOut = fn(msg: Confirmation, session_id: SessionID) -> Result<(), MessageRejectErrorEnum>;Expand description
RouteOut is the callback type for routing Confirmation messages.
pub type RouteOut = fn(msg: Confirmation, session_id: SessionID) -> Result<(), MessageRejectErrorEnum>;RouteOut is the callback type for routing Confirmation messages.